import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import errorHandler from '../error-handler';
import { wrapCollection } from '../common-utils';

function createTeamMembershipApi(http) {
  return {
    update: function update() {
      var raw = this.toPlainObject();
      var teamId = raw.sys.team.sys.id;
      return http.put('teams/' + teamId + '/team_memberships/' + this.sys.id, raw, {
        headers: {
          'X-Contentful-Version': this.sys.version || 0
        }
      }).then(function (response) {
        return wrapTeamMembership(http, response.data);
      }, errorHandler);
    },
    "delete": function _delete() {
      var raw = this.toPlainObject();
      var teamId = raw.sys.team.sys.id;
      return http["delete"]('teams/' + teamId + '/team_memberships/' + this.sys.id).then(function () {// do nothing
      }, errorHandler);
    }
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw team membership data
 * @return Wrapped team membership data
 */


export function wrapTeamMembership(http, data) {
  var teamMembership = toPlainObject(cloneDeep(data));
  var teamMembershipWithMethods = enhanceWithMethods(teamMembership, createTeamMembershipApi(http));
  return freezeSys(teamMembershipWithMethods);
}
/**
 * @private
 */

export var wrapTeamMembershipCollection = wrapCollection(wrapTeamMembership);