import { TagProps } from './entities/tag';
export interface DefaultElements<TPlainObject extends object = object> {
    toPlainObject(): TPlainObject;
}
/**
 * Link is a reference object to another entity that can be resolved using tools such as contentful-resolve
 */
export interface Link<T extends string> {
    sys: {
        type: 'Link';
        linkType: T;
        id: string;
    };
}
/** String will be in ISO8601 datetime format e.g. 2013-06-26T13:57:24Z */
export declare type ISO8601Timestamp = string;
export interface MetaSysProps {
    type: string;
    id: string;
    space?: {
        sys: MetaLinkProps;
    };
    status?: {
        sys: MetaLinkProps;
    };
    version: number;
    createdBy?: {
        sys: MetaLinkProps;
    };
    createdAt: string;
    updatedBy?: {
        sys: MetaLinkProps;
    };
    updatedAt: string;
    publishedVersion?: number;
    archivedVersion?: number;
}
export interface MetaLinkProps {
    type: string;
    linkType: string;
    id: string;
}
export interface MetadataProps {
    tags: TagProps[];
}
export interface CollectionProp<TObj> {
    sys: {
        type: 'Array';
    };
    total: number;
    skip: number;
    limit: number;
    items: TObj[];
}
export interface Collection<T, TPlain> extends CollectionProp<T>, DefaultElements<CollectionProp<TPlain>> {
}
export interface QueryOptions extends BasicQueryOptions {
    content_type?: string;
    include?: number;
}
export interface BasicQueryOptions {
    skip?: number;
    limit?: number;
    order?: string;
    [key: string]: any;
}
export interface BasicCursorPaginationOptions {
    prev?: string;
    next?: string;
}
